actionBuilder property
set bottom Bar Actions Widgets also you can set stack children widgets
Implementation
final Widget Function(BuildContext,VideoPlayerValue)? actionBuilder;
set bottom Bar Actions Widgets also you can set stack children widgets
final Widget Function(BuildContext,VideoPlayerValue)? actionBuilder;