addReloadOptionWhenFailed property

dynamic Function(VideoPlayerController)? addReloadOptionWhenFailed
final

when file or stream failed to load data add reload button with sending new video player controller

Implementation

final  Function(VideoPlayerController)? addReloadOptionWhenFailed;