onNavigate property
you can call this function if you specified custom navigator in your app
Implementation
final Function(Widget)? onNavigate;
you can call this function if you specified custom navigator in your app
final Function(Widget)? onNavigate;