applyOrientationsEnforcement property
this option will force the view port and the Preferred Orientations to be the same as the video Orientations
Implementation
final bool applyOrientationsEnforcement ;
this option will force the view port and the Preferred Orientations to be the same as the video Orientations
final bool applyOrientationsEnforcement ;