autoPauseAfterDispose property
when widget that hold sharara video player dispose , the player controller will automatically pause the video
set to false if you do not want that
Implementation
final bool autoPauseAfterDispose;
when widget that hold sharara video player dispose , the player controller will automatically pause the video
set to false if you do not want that
final bool autoPauseAfterDispose;